==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/admin/blocks.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");
include("../include/header.inc.php");

$VAR["Heading"] = _BLOCKS;

$out = new KWL_Html;

$VAR["Content"] = $out->table_start("100%",'',0,0,3);

if (!SqlCount("T_Blocks")) {
	$VAR["Content"] .= "<TR><TD>"._BLOCK_NOT."</TD></TR>\n";
} else {
	$VAR["Content"] .= "<TR><TH>"._BLOCK_DISP."</TH>".
                      "<TH>"._TITLE."</TH>".
                      "<TH>". _BLOCK_SORT ."</TH>".
                      "<TH>"._BLOCK_TYPE."</TH>".
                      "<TH>op</TH></TR>".
                      show_blocks("0").
                      show_blocks("p").
                      show_blocks("f").
                      show_blocks("l").
                      show_blocks("r");
}

$VAR["Content"] .= $out->table_end();
KWL_DrawMain($VAR);

$foo	= SqlCount("T_Blocks");
$bar	= empty($foo) ? 1 : $foo + 1;
$VAR["Heading"] = _BLOCK_ADD;
$VAR["Content"] = $out->form_start("admin/submit.php","Blocks").
                  $out->table_start("100%",'',0,0,3).
                  "<tr><td>". _BLOCK_DISP . ":</td>".
                  "<td>".
                  $out->select("Display",array( "l" => _BLOCK_LEFT,
                                                "r" => _BLOCK_RIGHT,
                                                "p" => _BLOCK_PAGE,
                                                "f" => _FEATURES )).
                  "</td></tr>".
                  "<tr><td>". _BLOCK_OPTION . ":</td>".
                  "<td>". _BLOCK_SORT .": ".
                  $out->input_form("text","OrderID",$bar,KWL_FormSize(3),3).
                  $out->check_box("ShowMain").
                  _BLOCK_STORY_ONLY ."</td></tr>\n".
                  "<tr><td>". _BLOCK_PAGE . " / " . _FEATURES . ":</td>".
                  "<td>". $out->check_box("PageComments") . _USERCOMMENT.
                  "</td></tr>\n".
                  "<tr><td>". _TITLE . ":</td>".
                  "<td>". $out->input_form("text","Heading",'',KWL_FormSize(20),48).
                  "</td></tr>\n".
                  "<tr><td colspan=2><hr>".
                  $out->radio("Type",array( 0 => "HTML" ),0).
                  "</td></tr><tr>\n".
                  "<td colspan = 2>".
                  KWL_FormResizer("Blocks.Content",$size['text'],10) ."<BR>".
                  $out ->textarea("Content",15,KWL_FormSize(22)).
                  "</td></tr>\n";

$s_block = array();
$sblock = "";
$result = SqlQuery("SELECT URL FROM T_Blocks WHERE Type = '3'");
while ($A = mysql_fetch_array($result)) $s_block[] = $A['URL'];
mysql_free_result($result);
if (!in_array("topic.php",$s_block)) $sblock .= "<option value=\"0\">". _TOPICS;
if (!in_array("older.php",$s_block)) $sblock .= "<option value=\"1\">". _OLDER;
if (!in_array("top5.php",$s_block)) $sblock .= "<option value=\"2\">". _TOP5;
if (!in_array("hot5.php",$s_block)) $sblock .= "<option value=\"3\">". _HOT5;
if (!in_array("lastc5.php",$s_block)) $sblock .= "<option value=\"4\">". _LASTC5;
if (!in_array("theme.php",$s_block)) $sblock .= "<option value=\"5\">". _THEME_USE;
if (!in_array("scroll.php",$s_block)) $sblock .= "<option value=\"6\">". _SCROLL_BLOCKA;
if (!in_array("login.php",$s_block)) $sblock .= "<option value=\"7\">". _LOGIN;
if (!in_array("poll.php",$s_block)) $sblock .= "<option value=\"8\">". _POLLS;
if (!in_array("feature.php",$s_block)) $sblock .= "<option value=\"9\">". _FEATURES;
if (!in_array("rlink.php",$s_block)) $sblock .= "<option value=\"10\">". _RANDOM_LINK;
if (!in_array("rbutton.php",$s_block)) $sblock .= "<option value=\"11\">". _RANDOM_BUTTON;

if ($sblock) {
   $VAR["Content"] .= "<tr><td colspan=2>".
                      $out->radio("Type",array( 3 => "System")).
                      "<select name=\"system\">$sblock</select></td></tr>\n";
}
$VAR["Content"] .= "<tr><td colspan=2>".
                   $out->radio("Type",array( 1 => "RDF")).
                   " (" . _BLOCK_RDF_SUPP .") <a href=\"rdf_host.php\" target=\"_blank\">host list</a>".
                   "</td></tr>\n".
                   "<tr><td colspan=2>".
                   $out->radio("Type",array( 2 => "INCLUDE")).
                   " (". _BLOCK_INCLUDE .")" . "</td></tr>\n".
                   "<tr><td>URL:</td>".
                   "<td>". $out->input_form("text","SrcURL",'',KWL_FormSize(15),96).
                   "</td></tr>\n".
                   "<tr><td>". _BLOCK_CACHE .":</td>".
                   "<td>". $out->input_form("text","Cache",60,4,4).
                   "("._BLOCK_CACHE_DESC.")</td></tr>\n".
                   "<tr><td>". _MAX_ITEMS .":</td>".
                   "<td>". $out->input_form("text","MaxItem",10,4,3).
                   " (RSS/RDF)</td></tr>\n".
                   "<tr><td colspan=2>".
                   $out->input_form("hidden","what","block").
                   $out->input_form("submit",'',KWL_SubmitButton()) . "</td></tr>".
                   $out->table_end() . $out->form_end();                   
KWL_DrawMain($VAR);
include("../include/footer.inc.php");

function show_blocks($t) {
   $return = "";
   $result = SqlQuery("SELECT * FROM T_Blocks WHERE Display = '$t' ORDER BY OrderID");
   if (!mysql_num_rows($result)) return;
   while ($A = mysql_fetch_array($result)) {
      switch ($A['Type']) {
         case "0": $tmp 	= "HTML"; break;
         case "1": $tmp 	= "RDF"; break;
         case "2": $tmp 	= "URL"; break;
         case "3": $tmp 	= "System"; break;
      }
		switch ($A['Display']) {
         case "0": $show = _BLOCK_OFF; break;
         case "l": $show = _BLOCK_LEFT; break;
         case "r": $show = _BLOCK_RIGHT; break;
         case "p": $show = _BLOCK_PAGE; break;
         case "f": $show = _FEATURES; break;
      }
      if ($A['Type'] == 3) $A['Heading'] = KWL_SblockTitle($A['URL'],1);
      $return .= "<TR><TD>" . $show . "</TD>".
                 "<TD>". KWL_PrepareHtml($A['Heading']) ."</TD>".
                 "<TD>". $A['OrderID'] ."</TD>".
                 "<TD>". $tmp ."</TD>".
                 "<TD>". KWL_AdminLinki("T_Blocks",$A["Rid"],"admin/blocks.php").
                 "</TD></TR>\n";
	}
   if (!empty($return)) return $return ."<TR><TD COLSPAN=5><HR></TD></TR>\n";
}
?>

==> korweblog-1.5.9.tar.gz: korweblog-1.5.9/admin/blocks.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");
include("../include/header.inc.php");

$VAR["Heading"] = _BLOCKS;

$out = new KWL_Html;

$VAR["Content"] = $out->table_start("100%",'',0,0,3);

if (!SqlCount("T_Blocks")) {
	$VAR["Content"] .= "<TR><TD>"._BLOCK_NOT."</TD></TR>\n";
} else {
	$VAR["Content"] .= "<TR><TH>"._BLOCK_DISP."</TH>".
                      "<TH>"._TITLE."</TH>".
                      "<TH>". _BLOCK_SORT ."</TH>".
                      "<TH>"._BLOCK_TYPE."</TH>".
                      "<TH>op</TH></TR>".
                      show_blocks("0").
                      show_blocks("p").
                      show_blocks("f").
                      show_blocks("l").
                      show_blocks("r");
}

$VAR["Content"] .= $out->table_end();
KWL_DrawMain($VAR);

$foo	= SqlCount("T_Blocks");
$bar	= empty($foo) ? 1 : $foo + 1;
$VAR["Heading"] = _BLOCK_ADD;
$VAR["Content"] = $out->form_start("admin/submit.php","Blocks").
                  $out->table_start("100%",'',0,0,3).
                  "<tr><td>". _BLOCK_DISP . ":</td>".
                  "<td>".
                  $out->select("Display",array( "l" => _BLOCK_LEFT,
                                                "r" => _BLOCK_RIGHT,
                                                "p" => _BLOCK_PAGE,
                                                "f" => _FEATURES )).
                  "</td></tr>".
                  "<tr><td>". _BLOCK_OPTION . ":</td>".
                  "<td>". _BLOCK_SORT .": ".
                  $out->input_form("text","OrderID",$bar,KWL_FormSize(3),3).
                  $out->check_box("ShowMain").
                  _BLOCK_STORY_ONLY ."</td></tr>\n".
                  "<tr><td>". _BLOCK_PAGE . " / " . _FEATURES . ":</td>".
                  "<td>". $out->check_box("PageComments") . _USERCOMMENT.
                  "</td></tr>\n".
                  "<tr><td>". _TITLE . ":</td>".
                  "<td>". $out->input_form("text","Heading",'',KWL_FormSize(20),48).
                  "</td></tr>\n".
                  "<tr><td colspan=2><hr>".
                  $out->radio("Type",array( 0 => "HTML" ),0).
                  "</td></tr><tr>\n".
                  "<td colspan = 2>".
                  KWL_FormResizer("Blocks.Content",$size['text'],10) ."<BR>".
                  $out ->textarea("Content",15,KWL_FormSize(22)).
                  "</td></tr>\n";

$s_block = array();
$sblock = "";
$result = SqlQuery("SELECT URL FROM T_Blocks WHERE Type = '3'");
while ($A = mysql_fetch_array($result)) $s_block[] = $A['URL'];
mysql_free_result($result);
if (!in_array("topic.php",$s_block)) $sblock .= "<option value=\"0\">". _TOPICS;
if (!in_array("older.php",$s_block)) $sblock .= "<option value=\"1\">". _OLDER;
if (!in_array("top5.php",$s_block)) $sblock .= "<option value=\"2\">". _TOP5;
if (!in_array("hot5.php",$s_block)) $sblock .= "<option value=\"3\">". _HOT5;
if (!in_array("lastc5.php",$s_block)) $sblock .= "<option value=\"4\">". _LASTC5;
if (!in_array("theme.php",$s_block)) $sblock .= "<option value=\"5\">". _THEME_USE;
if (!in_array("scroll.php",$s_block)) $sblock .= "<option value=\"6\">". _SCROLL_BLOCKA;
if (!in_array("login.php",$s_block)) $sblock .= "<option value=\"7\">". _LOGIN;
if (!in_array("poll.php",$s_block)) $sblock .= "<option value=\"8\">". _POLLS;
if (!in_array("feature.php",$s_block)) $sblock .= "<option value=\"9\">". _FEATURES;
if (!in_array("rlink.php",$s_block)) $sblock .= "<option value=\"10\">". _RANDOM_LINK;
if (!in_array("rbutton.php",$s_block)) $sblock .= "<option value=\"11\">". _RANDOM_BUTTON;

if ($sblock) {
   $VAR["Content"] .= "<tr><td colspan=2>".
                      $out->radio("Type",array( 3 => "System")).
                      "<select name=\"system\">$sblock</select></td></tr>\n";
}
$VAR["Content"] .= "<tr><td colspan=2>".
                   $out->radio("Type",array( 1 => "RDF")).
                   " (" . _BLOCK_RDF_SUPP .")".
                   "</td></tr>\n".
                   "<tr><td colspan=2>".
                   $out->radio("Type",array( 2 => "INCLUDE")).
                   " (". _BLOCK_INCLUDE .")" . "</td></tr>\n".
                   "<tr><td>URL:</td>".
                   "<td>". $out->input_form("text","SrcURL",'',KWL_FormSize(15),96).
                   "</td></tr>\n".
                   "<tr><td>". _BLOCK_CACHE .":</td>".
                   "<td>". $out->input_form("text","Cache",60,4,4).
                   "("._BLOCK_CACHE_DESC.")</td></tr>\n".
                   "<tr><td>". _MAX_ITEMS .":</td>".
                   "<td>". $out->input_form("text","MaxItem",10,4,3).
                   " (RSS/RDF)</td></tr>\n".
                   "<tr><td colspan=2>".
                   $out->input_form("hidden","what","block").
                   $out->input_form("submit",'',KWL_SubmitButton()) . "</td></tr>".
                   $out->table_end() . $out->form_end();                   
KWL_DrawMain($VAR);
include("../include/footer.inc.php");

function show_blocks($t) {
   $return = "";
   $result = SqlQuery("SELECT * FROM T_Blocks WHERE Display = '$t' ORDER BY OrderID");
   if (!mysql_num_rows($result)) return;
   while ($A = mysql_fetch_array($result)) {
      switch ($A['Type']) {
         case "0": $tmp 	= "HTML"; break;
         case "1": $tmp 	= "RDF"; break;
         case "2": $tmp 	= "URL"; break;
         case "3": $tmp 	= "System"; break;
      }
		switch ($A['Display']) {
         case "0": $show = _BLOCK_OFF; break;
         case "l": $show = _BLOCK_LEFT; break;
         case "r": $show = _BLOCK_RIGHT; break;
         case "p": $show = _BLOCK_PAGE; break;
         case "f": $show = _FEATURES; break;
      }
      if ($A['Type'] == 3) $A['Heading'] = KWL_SblockTitle($A['URL'],1);
      $return .= "<TR><TD>" . $show . "</TD>".
                 "<TD>". KWL_PrepareHtml($A['Heading']) ."</TD>".
                 "<TD>". $A['OrderID'] ."</TD>".
                 "<TD>". $tmp ."</TD>".
                 "<TD>". KWL_AdminLinki("T_Blocks",$A["Rid"],"admin/blocks.php").
                 "</TD></TR>\n";
	}
   if (!empty($return)) return $return ."<TR><TD COLSPAN=5><HR></TD></TR>\n";
}
?>
